@@ -1,9 +1,9 @@
+"""Module provider for Softlayer"""
 from __future__ import absolute_import
 import logging
 
 from lexicon.providers.base import Provider as BaseProvider
 
-
 try:
     import SoftLayer
 except ImportError:
@@ -14,7 +14,8 @@ LOGGER = logging.getLogger(__name__)
 NAMESERVER_DOMAINS = ['softlayer.com']
 
 
-def ProviderParser(subparser):
+def provider_parser(subparser):
+    """Generate a provider parser for Softlayer"""
     subparser.add_argument(
         "--auth-username", help="specify username for authentication")
     subparser.add_argument(
@@ -22,7 +23,7 @@ def ProviderParser(subparser):
 
 
 class Provider(BaseProvider):
-
+    """Provider class for Softlayer"""
     def __init__(self, config):
         super(Provider, self).__init__(config)
         self.domain_id = None
@@ -38,15 +39,16 @@ class Provider(BaseProvider):
         self.sl_dns = SoftLayer.managers.dns.DNSManager(sl_client)
 
     # Authenticate against provider,
-    # Make any requests required to get the domain's id for this provider, so it can be used in subsequent calls.
-    # Should throw an error if authentication fails for any reason, of if the domain does not exist.
-
-    def authenticate(self):
+    # Make any requests required to get the domain's id for this provider,
+    # so it can be used in subsequent calls.
+    # Should throw an error if authentication fails for any reason,
+    # of if the domain does not exist.
+    def _authenticate(self):
         domain = self.domain
 
         payload = self.sl_dns.resolve_ids(domain)
 
-        if len(payload) < 1:
+        if not payload:
             raise Exception('No domain found')
         if len(payload) > 1:
             raise Exception('Too many domains found. This should not happen')
@@ -56,9 +58,9 @@ class Provider(BaseProvider):
 
     # Create record. If record already exists with the same content, do nothing
 
-    def create_record(self, type, name, content):
-        records = self.list_records(type, name, content)
-        if len(records) > 0:
+    def _create_record(self, rtype, name, content):
+        records = self._list_records(rtype, name, content)
+        if records:
             # Nothing to do, record already exists
             LOGGER.debug('create_record: already exists')
             return True
@@ -66,7 +68,7 @@ class Provider(BaseProvider):
         name = self._relative_name(name)
         ttl = self._get_lexicon_option('ttl')
         payload = self.sl_dns.create_record(
-            self.domain_id, name, type, content, ttl)
+            self.domain_id, name, rtype, content, ttl)
 
         LOGGER.debug('create_record: %s', payload)
         return True
@@ -75,13 +77,13 @@ class Provider(BaseProvider):
     # type, name and content are used to filter records.
     # If possible filter during the query, otherwise filter after response is received.
 
-    def list_records(self, type=None, name=None, content=None):
+    def _list_records(self, rtype=None, name=None, content=None):
         ttl = None
         if name:
             name = self._relative_name(name)
 
         payload = self.sl_dns.get_records(
-            self.domain_id, ttl, content, name, type)
+            self.domain_id, ttl, content, name, rtype)
 
         records = []
         for record in payload:
@@ -100,17 +102,17 @@ class Provider(BaseProvider):
     # Update a record.
     # If an identifier is specified, use it, otherwise do a lookup using type and name.
 
-    def update_record(self, identifier=None, type=None, name=None, content=None):
+    def _update_record(self, identifier=None, rtype=None, name=None, content=None):
         if not identifier:
-            records = self.list_records(type, name)
+            records = self._list_records(rtype, name)
             if len(records) == 1:
                 identifier = records[0]['id']
             else:
                 raise Exception('Record identifier could not be found.')
 
         record = {'id': identifier}
-        if type:
-            record['type'] = type
+        if rtype:
+            record['type'] = rtype
         if name:
             record['host'] = self._relative_name(name)
         if content:
@@ -127,10 +129,10 @@ class Provider(BaseProvider):
     # If record does not exist, do nothing.
     # If an identifier is specified, use it, otherwise do a lookup using type, name and content.
 
-    def delete_record(self, identifier=None, type=None, name=None, content=None):
+    def _delete_record(self, identifier=None, rtype=None, name=None, content=None):
         delete_record_id = []
         if not identifier:
-            records = self.list_records(type, name, content)
+            records = self._list_records(rtype, name, content)
             delete_record_id = [record['id'] for record in records]
         else:
             delete_record_id.append(identifier)
@@ -142,3 +144,7 @@ class Provider(BaseProvider):
 
         LOGGER.debug('delete_record: %s', True)
         return True
+
+    def _request(self, action='GET', url='/', data=None, query_params=None):
+        # Helper _request is not used in Softlayer
+        pass
